Enum rkyv::ser::serializers::AllocScratchError [−][src]
pub enum AllocScratchError {
ExceededLimit {
requested: usize,
remaining: usize,
},
NotPoppedInReverseOrder {
expected: *mut u8,
expected_layout: Layout,
actual: *mut u8,
actual_layout: Layout,
},
NoAllocationsToPop,
}Expand description
Errors that can occur when allocating with the global allocator.
Variants
ExceededLimit
Fields
requested: usizeThe amount of scratch space requested
remaining: usizeThe amount of scratch space remaining
The amount of scratch space requested exceeded the maximum limit
NotPoppedInReverseOrder
Fields
expected_layout: LayoutThe layout of the allocation that was expected to be next
actual_layout: LayoutThe layout of the pointer that was popped instead
Scratch space was not popped in reverse order.
NoAllocationsToPop
There are no allocations to pop