Enum rkyv::ser::serializers::FixedSizeScratchError [−][src]
pub enum FixedSizeScratchError {
OutOfScratch(Layout),
NotPoppedInReverseOrder {
pos: usize,
next_pos: usize,
next_size: usize,
},
UnownedAllocation,
}Expand description
Errors that can occur when using a fixed-size allocator.
Pairing a fixed-size allocator with a fallback allocator can help prevent running out of scratch space unexpectedly.
Variants
OutOfScratch(Layout)
Tuple Fields
0: LayoutThe allocator ran out of scratch space.
NotPoppedInReverseOrder
Fields
pos: usizeThe current position of the start of free memory
next_pos: usizeThe next position according to the erroneous pop
next_size: usizeThe size of the memory according to the erroneous pop
Scratch space was not popped in reverse order.
UnownedAllocation
The given allocation did not belong to the scratch allocator.